package
Version:
v0.0.0-...-6e4230c
Opens a new window with list of versions in this module.
Published: Dec 12, 2016
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func CopyHelper(key string, from, to interface{}) error
CopyHelper helps to reflect copy (inject) some values
Source Files
¶
Click to show internal directories.
Click to hide internal directories.